@@ -140,7 +140,7 @@ def parse_3ox(threeshape_file: Path):
 
                 model_fdi = unn_to_fdi(int(model_path.split('_')[-1].split('.')[0]))
 
-                model_tooth = Tooth(fdi=model_fdi, color=None, implant_type=None, type='modeldie', is_anatomical=False)
+                model_tooth = Tooth(fdi=model_fdi, color=None, implant_type=None, implant_system=None, type='modeldie', is_anatomical=False)
 
                 model = Element(file_name=model_path, material=model_material, color=model_color, height=model_height, type='modeldie', teeth=[model_tooth], is_screw_retained=False)
                 models.append(model)
@@ -159,9 +159,10 @@ def parse_3ox(threeshape_file: Path):
 
             tooth_type = tooth_node.get('typeClass')
             implant_type = tooth_node.get('abutmentKitID')
+            implant_system = tooth_node.get('implantSystemID')
 
             tooth = Tooth(fdi=fdi, color=tooth_color, type=tooth_type, is_anatomical=None,
-                    implant_type=implant_type)
+                    implant_type=implant_type, implant_system=implant_system)
             teeth.append(tooth)
 
         for scan_node in element_node.findall('ns:ScanFiles/ns:ScanFile', namespaces=nsmap):
